/'*****************************************************************************
 * libvlc.h:  libvlc external API
 *****************************************************************************
 * Copyright (C) 1998-2009 the VideoLAN team
 * $Id: 5f3b52b14616e057024858eebba05a7ac6eb5729 $
 *
 * Authors: Clément Stenac <zorglub@videolan.org>
 *          Jean-Paul Saman <jpsaman@videolan.org>
 *          Pierre d'Herbemont <pdherbemont@videolan.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

/**
 * \file
 * This file defines libvlc external API
 */

/**
 * \defgroup libvlc LibVLC
 * LibVLC is the external programming interface of the VLC media player.
 * It is used to embed VLC into other applications or frameworks.
 * @{
 *'/

#Ifndef __libvlc_bi__
#define __libvlc_bi__

#define VLC_LIBVLC_H 1

#Include Once "vlc/libvlc_structures.bi"
#Include Once "vlc/libvlc_events.bi"
#Include Once "crt/stdarg.bi"

Extern "C"

Declare Function libvlc_errmsg () As ZString Ptr
Declare Sub libvlc_clearerr ()
Declare Function libvlc_printerr (ByVal fmt As ZString Ptr, ...) As ZString Ptr
Declare Function libvlc_new (ByVal argc As Integer, ByVal argv As Byte Ptr Ptr) As libvlc_instance_t Ptr
Declare Sub libvlc_release (ByVal p_instance As libvlc_instance_t Ptr)
Declare Sub libvlc_retain (ByVal p_instance As libvlc_instance_t Ptr)
Declare Function libvlc_add_intf (ByVal p_instance As libvlc_instance_t Ptr, ByVal Name As ZString Ptr) As Integer
Declare Sub libvlc_wait (ByVal p_instance As libvlc_instance_t Ptr)
Declare Function libvlc_get_version () As ZString Ptr
Declare Function libvlc_get_compiler () As ZString Ptr
Declare Function libvlc_get_changeset () As ZString Ptr

Type libvlc_event_manager_t As Any
Type libvlc_event_type_t As Integer
Type libvlc_callback_t As Sub (ByVal As libvlc_event_t Ptr, ByVal As Any Ptr)
Type libvlc_log_cb As Sub (Data As Any Ptr, level As Integer, ctx As libvlc_log_t Ptr, fmt As ZString Ptr, args As va_list)
Type libvlc_module_description_t
	psz_name As ZString Ptr
	psz_shortname As ZString Ptr
	psz_longname As ZString Ptr
	psz_help As ZString Ptr
	p_next As libvlc_module_description_t Ptr
End Type

Declare Function libvlc_event_attach (ByVal p_event_manager As libvlc_event_manager_t Ptr, ByVal i_event_type As libvlc_event_type_t, ByVal f_callback As libvlc_callback_t, ByVal user_data As Any Ptr) As Integer
Declare Sub libvlc_event_detach (ByVal p_event_manager As libvlc_event_manager_t Ptr, ByVal i_event_type As libvlc_event_type_t, ByVal f_callback As libvlc_callback_t, ByVal p_user_data As Any Ptr)
Declare Function libvlc_event_type_name (ByVal event_type As libvlc_event_type_t) As ZString Ptr
Declare Function libvlc_get_log_verbosity (ByVal p_instance As libvlc_instance_t Ptr) As UInteger
Declare Sub libvlc_set_log_verbosity (ByVal p_instance As libvlc_instance_t Ptr, ByVal level As UInteger)
Declare Function libvlc_log_open (ByVal p_instance As libvlc_instance_t Ptr) As libvlc_log_t Ptr
Declare Sub libvlc_log_close (ByVal p_log As libvlc_log_t Ptr)
Declare Function libvlc_log_count (ByVal p_log As libvlc_log_t Ptr) As UInteger
Declare Sub libvlc_log_clear (ByVal p_log As libvlc_log_t Ptr)
Declare Function libvlc_log_get_iterator (ByVal p_log As libvlc_log_t Ptr) As libvlc_log_iterator_t Ptr
Declare Sub libvlc_log_iterator_free (ByVal p_iter As libvlc_log_iterator_t Ptr)
Declare Function libvlc_log_iterator_has_next (ByVal p_iter As libvlc_log_iterator_t Ptr) As Integer
Declare Function libvlc_log_iterator_next (ByVal p_iter As libvlc_log_iterator_t Ptr, ByVal p_buffer As libvlc_log_message_t Ptr) As libvlc_log_message_t Ptr
Declare Function libvlc_clock () As int64_t
Declare Sub libvlc_free (Ptr As Any Ptr)
Declare Sub libvlc_log_get_context (ctx As Any Ptr Ptr, module As ZString Ptr, file As ZString Ptr, Line As UInteger Ptr)
Declare Sub libvlc_log_get_object (ctx As libvlc_log_t Ptr, Name As ZString Ptr Ptr, header As ZString Ptr Ptr, id As uintptr_t Ptr)
Declare Sub libvlc_log_set (As libvlc_instance_t Ptr, cb As libvlc_log_cb, Data As Any Ptr)
Declare Sub libvlc_log_set_file (As libvlc_instance_t Ptr, stream As Any Ptr)
Declare Sub libvlc_log_unset (As libvlc_instance_t Ptr)
Declare Sub libvlc_module_description_list_release (p_list As libvlc_module_description_t Ptr)
Declare Sub libvlc_set_app_id (p_instance As libvlc_instance_t Ptr, id As ZString Ptr, version As ZString Ptr, icon As ZString Ptr)
Declare Sub libvlc_set_exit_handler (p_instance As libvlc_instance_t Ptr, cb As Sub (As Any Ptr), opaque As Any Ptr)
Declare Sub libvlc_set_user_agent (p_instance As libvlc_instance_t Ptr, Name As ZString Ptr,http As ZString Ptr)
Declare Function libvlc_video_filter_list_get (p_instance As libvlc_instance_t Ptr) As libvlc_module_description_t Ptr
Declare Function libvlc_vprinterr (fmt As ZString Ptr, ap As va_list) As ZString Ptr
Declare Function libvlc_audio_filter_list_get(p_instance As libvlc_instance_t Ptr) As libvlc_module_description_t Ptr


Function libvlc_delay(pts As int64_t) As int64_t
	Return pts - libvlc_clock()
End Function


End Extern

#EndIf
