/'*****************************************************************************
 * libvlc_vlm.h:  libvlc_* new external API
 *****************************************************************************
 * Copyright (C) 1998-2008 the VideoLAN team
 * $Id: f09dbe506ef2f21b2d894e9086d91e11672bf2b9 $
 *
 * Authors: Clément Stenac <zorglub@videolan.org>
 *          Jean-Paul Saman <jpsaman _at_ m2x _dot_ nl>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************'/

#Ifndef __libvlc_vlm_bi__
#define __libvlc_vlm_bi__

#define LIBVLC_VLM_H 1

/'*****************************************************************************
 * VLM
 *****************************************************************************'/

Extern "C"

' * Release the vlm instance related to the given libvlc_instance_t
Declare Sub libvlc_vlm_release( p_instance As libvlc_instance_t Ptr )

/'**
 * Add a broadcast, with one input.
 *
 * \param p_instance the instance
 * \param psz_name the name of the new broadcast
 * \param psz_input the input MRL
 * \param psz_output the output MRL (the parameter to the "sout" variable)
 * \param i_options number of additional options
 * \param ppsz_options additional options
 * \param b_enabled boolean for enabling the new broadcast
 * \param b_loop Should this broadcast be played in loop ?
 * \return 0 on success, -1 on error
 *'/
Declare Function libvlc_vlm_add_broadcast (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr, ByVal psz_input As ZString Ptr, ByVal psz_output As ZString Ptr, ByVal i_options As Integer, ByVal ppsz_options As Byte Ptr Ptr, ByVal b_enabled As Integer, ByVal b_loop As Integer) As Integer

/'**
 * Add a vod, with one input.
 *
 * \param p_instance the instance
 * \param psz_name the name of the new vod media
 * \param psz_input the input MRL
 * \param i_options number of additional options
 * \param ppsz_options additional options
 * \param b_enabled boolean for enabling the new vod
 * \param psz_mux the muxer of the vod media
 * \return 0 on success, -1 on error
 *'/
Declare Function libvlc_vlm_add_vod (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr, ByVal psz_input As ZString Ptr, ByVal i_options As Integer, ByVal ppsz_options As Byte Ptr Ptr, ByVal b_enabled As Integer, ByVal psz_mux As ZString Ptr) As Integer

/'**
 * Delete a media (VOD or broadcast).
 *
 * \param p_instance the instance
 * \param psz_name the media to delete
 * \return 0 on success, -1 on error
 *'/
Declare Function libvlc_vlm_del_media (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr) As Integer

/'**
 * Enable or disable a media (VOD or broadcast).
 *
 * \param p_instance the instance
 * \param psz_name the media to work on
 * \param b_enabled the new status
 * \return 0 on success, -1 on error
 *'/
Declare Function libvlc_vlm_set_enabled (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr, ByVal b_enabled As Integer) As Integer

/'**
 * Set the output for a media.
 *
 * \param p_instance the instance
 * \param psz_name the media to work on
 * \param psz_output the output MRL (the parameter to the "sout" variable)
 * \return 0 on success, -1 on error
 *'/
Declare Function libvlc_vlm_set_output (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr, ByVal psz_output As ZString Ptr) As Integer

/'**
 * Set a media's input MRL. This will delete all existing inputs and
 * add the specified one.
 *
 * \param p_instance the instance
 * \param psz_name the media to work on
 * \param psz_input the input MRL
 * \return 0 on success, -1 on error
 *'/
Declare Function libvlc_vlm_set_input (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr, ByVal psz_input As ZString Ptr) As Integer

/'**
 * Add a media's input MRL. This will add the specified one.
 *
 * \param p_instance the instance
 * \param psz_name the media to work on
 * \param psz_input the input MRL
 * \return 0 on success, -1 on error
 *'/
Declare Function libvlc_vlm_add_input (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr, ByVal psz_input As ZString Ptr) As Integer

/'**
 * Set a media's loop status.
 *
 * \param p_instance the instance
 * \param psz_name the media to work on
 * \param b_loop the new status
 * \return 0 on success, -1 on error
 *'/
Declare Function libvlc_vlm_set_loop (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr, ByVal b_loop As Integer) As Integer

/'**
 * Set a media's vod muxer.
 *
 * \param p_instance the instance
 * \param psz_name the media to work on
 * \param psz_mux the new muxer
 * \return 0 on success, -1 on error
 *'/
Declare Function libvlc_vlm_set_mux (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr, ByVal psz_mux As ZString Ptr) As Integer

/'**
 * Edit the parameters of a media. This will delete all existing inputs and
 * add the specified one.
 *
 * \param p_instance the instance
 * \param psz_name the name of the new broadcast
 * \param psz_input the input MRL
 * \param psz_output the output MRL (the parameter to the "sout" variable)
 * \param i_options number of additional options
 * \param ppsz_options additional options
 * \param b_enabled boolean for enabling the new broadcast
 * \param b_loop Should this broadcast be played in loop ?
 * \return 0 on success, -1 on error
 *'/
Declare Function libvlc_vlm_change_media (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr, ByVal psz_input As ZString Ptr, ByVal psz_output As ZString Ptr, ByVal i_options As Integer, ByVal ppsz_options As Byte Ptr Ptr, ByVal b_enabled As Integer, ByVal b_loop As Integer) As Integer

/'**
 * Play the named broadcast.
 *
 * \param p_instance the instance
 * \param psz_name the name of the broadcast
 * \return 0 on success, -1 on error
 *'/
Declare Function libvlc_vlm_play_media (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr) As Integer

/'**
 * Stop the named broadcast.
 *
 * \param p_instance the instance
 * \param psz_name the name of the broadcast
 * \return 0 on success, -1 on error
 *'/
Declare Function libvlc_vlm_stop_media (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr) As Integer

/'**
 * Pause the named broadcast.
 *
 * \param p_instance the instance
 * \param psz_name the name of the broadcast
 * \return 0 on success, -1 on error
 *'/
Declare Function libvlc_vlm_pause_media (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr) As Integer

/'**
 * Seek in the named broadcast.
 *
 * \param p_instance the instance
 * \param psz_name the name of the broadcast
 * \param f_percentage the percentage to seek to
 * \return 0 on success, -1 on error
 *'/
Declare Function libvlc_vlm_seek_media (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr, ByVal f_percentage As Single) As Integer

/'**
 * Return information about the named media as a JSON
 * string representation.
 *
 * This function is mainly intended for debugging use,
 * if you want programmatic access to the state of
 * a vlm_media_instance_t, please use the corresponding
 * libvlc_vlm_get_media_instance_xxx -functions.
 * Currently there are no such functions available for
 * vlm_media_t though.
 *
 * \param p_instance the instance
 * \param psz_name the name of the media,
 *      if the name is an empty string, all media is described
 * \return string with information about named media, or NULL on error
 *'/
Declare Function libvlc_vlm_show_media (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr) As ZString Ptr

/'**
 * Get vlm_media instance position by name or instance id
 *
 * \param p_instance a libvlc instance
 * \param psz_name name of vlm media instance
 * \param i_instance instance id
 * \return position as float or -1. on error
 *'/
Declare Function libvlc_vlm_get_media_instance_position (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr, ByVal i_instance As Integer) As Single

/'**
 * Get vlm_media instance time by name or instance id
 *
 * \param p_instance a libvlc instance
 * \param psz_name name of vlm media instance
 * \param i_instance instance id
 * \return time as integer or -1 on error
 *'/
Declare Function libvlc_vlm_get_media_instance_time (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr, ByVal i_instance As Integer) As Integer

/'**
 * Get vlm_media instance length by name or instance id
 *
 * \param p_instance a libvlc instance
 * \param psz_name name of vlm media instance
 * \param i_instance instance id
 * \return length of media item or -1 on error
 *'/
Declare Function libvlc_vlm_get_media_instance_length (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr, ByVal i_instance As Integer) As Integer

/'**
 * Get vlm_media instance playback rate by name or instance id
 *
 * \param p_instance a libvlc instance
 * \param psz_name name of vlm media instance
 * \param i_instance instance id
 * \return playback rate or -1 on error
 *'/
Declare Function libvlc_vlm_get_media_instance_rate Cdecl (ByVal p_instance As libvlc_instance_t Ptr, ByVal psz_name As ZString Ptr, ByVal i_instance As Integer) As Integer


/'**
 * Get libvlc_event_manager from a vlm media.
 * The p_event_manager is immutable, so you don't have to hold the lock
 *
 * \param p_instance a libvlc instance
 * \return libvlc_event_manager
 *'/
Declare Function libvlc_vlm_get_event_manager Cdecl (p_instance As libvlc_instance_t Ptr) As libvlc_event_manager_t Ptr

End Extern

#EndIf
